@@ -53,6 +53,7 @@ class TokenClassificationBenchmark(BaseBenchmark, ABC):
                  learning_rate: float = 2e-5,
                  warmup_steps: int = 50,
                  batch_size: int = 16,
+                 evaluate_train: bool = False,
                  multilabel: bool = False,
                  split_point: Optional[int] = None,
                  verbose: bool = False):
@@ -65,6 +66,7 @@ class TokenClassificationBenchmark(BaseBenchmark, ABC):
                          epochs=epochs,
                          warmup_steps=warmup_steps,
                          batch_size=batch_size,
+                         evaluate_train=evaluate_train,
                          multilabel=multilabel,
                          split_point=split_point,
                          verbose=verbose)
